@@ -226,7 +226,7 @@ class Autograder(object):
         return self._set_question(label, [], [], None, None)
         
     def _set_question(self, label, parameters, answer, description, tag):
-        j = {'parameters':parameters, 'answer': [jsonable(a) for a in answer]}
+        j = {'parameters':jsonable(parameters), 'answer': [jsonable(a) for a in answer]}
         if description is not None:
             j['description'] = description.strip()
         if tag is not None:
@@ -305,6 +305,7 @@ class Samples:
         return self
     def conf(self, conf, scalar_conf):
         import scipy.stats
+        import numpy as np
         if len(set(self._list)) == 1:
             return scalar_conf(self._list[0])
         x = np.array(self._list)
